itf(resp, ip, item, stat = "lr", theta, groups,
standardize=TRUE, mu=0, sigma=1, do.plot = TRUE, main = "Item fit")resp, row of ip),
for which fit is to be tested"chi"
or "lr". Default is "lr". See details below.resp. If not given (and group is also missing),
EAP estimates will be computed from respgrp.
If not given, grp will be applied on theta with its
default values.itf with stat="chi",
and the second with stat="lr" (or not specifying stat at all).
In the real world we can only work with estimates of ability, not with ability
itself, so the approach is a bit circular in defining the groups.
I have tried to offer some
extra flexibility with the arguments theta nor group:
thetanorgroupis specified,item.testwill compute EAP estimates of ability for the proposed model, group them,
and use medians for"chi"or means for"lr". This is the
approximate behaviour of BILOG (assumingstat="lr").qrsand passing
them toitem.testastheta."chi", means for"lr")
can be overriden by preparing the groups withgrpand passing
them toitem.testasgroup. In that case,thetais not
needed.item.test will issue a warning.
For tests of 10 items or less, BILOG has a special statistic of fit, which
can be found in the BILOG output. Also of interest is the fit in 2- and
3-way marginal tables in package ltm.grp, eap, qrsdata(Scored)
p.2pl <- est(Scored, model="2PL", engine="ltm")
fit <- itf(resp=Scored, ip=p.2pl, item=7)Run the code above in your browser using DataLab