read.ip.bilog: Read in parameter estimates
Description
From BILOG output, read in estimates of item parameters.
Invoked automatically when the model is estimated via
irtoys. If that is not the case, file
must be a file produced with the >SAVE PARm file;
command in BILOG.Value
- A matrix with one row per item, and three columns: [,1] item
discrimination $a$, [,2] item difficulty $b$, and
[,3] asymptote $c$. For the 1PL and 2PL models, all
asymptotes are equal to 0; for the 1PL, the discriminations
are all equal but not necessarily equal to 1.