ip
Item parameters: a matrix with one row per item, and three columns: [,1] item
discrimination $a$, [,2] item difficulty $b$, and
[,3] asymptote $c$.
theta
An object containing ability estimates, as output by function mlebme or eap.
If NULL, MLE will be estimated from resp and ip.